@@ -7,7 +7,7 @@ use Sentry::Client;
 use Sentry::Hub;
 use Sentry::Logger 'logger';
 
-our $VERSION = version->declare('1.3.3');
+our $VERSION = version->declare('1.3.4');
 
 sub _call_on_hub ($method, @args) {
   my $hub = Sentry::Hub->get_current_hub();
@@ -22,7 +22,7 @@ sub _call_on_hub ($method, @args) {
 
 sub _init_and_bind ($options) {
   my $hub    = Sentry::Hub->get_current_hub();
-  my $client = Sentry::Client->new(_options => $options);
+  my $client = $options->{dsn} ? Sentry::Client->new(_options => $options) : undef;
   $hub->bind_client($client);
 }
 
